@@ -29,6 +29,8 @@
  */
 #define GIDSIZE 200
 
+#define KUNLUN_INTERNAL_STMT_SP "_kunlun_stmt_SP"
+
 /*
  * Xact isolation levels
  */
@@ -39,6 +41,7 @@
 
 extern int	DefaultXactIsoLevel;
 extern PGDLLIMPORT int XactIsoLevel;
+extern bool enable_auto_commit;
 
 /*
  * We implement three isolation levels internally.
@@ -86,6 +89,9 @@ extern int	synchronous_commit;
  */
 extern int	MyXactFlags;
 
+/* Flags bits to record events which occur on the current top level query */
+extern int	MyCommandFlags;
+
 /*
  * XACT_FLAGS_ACCESSEDTEMPREL - set when a temporary relation is accessed. We
  * don't allow PREPARE TRANSACTION in that case.
@@ -104,6 +110,34 @@ extern int	MyXactFlags;
  */
 #define XACT_FLAGS_ACCESSEDTEMPNAMESPACE		(1U << 2)
 
+/*
+ * XACT_FLAGS_EXECUTENONINTERNALFUNC - set when execute a function or procedure
+ * defined in non internal language (plpgsql, python ...)
+ */
+#define XACT_FLAGS_EXECUTENONINTERNALFUNC		(1U << 3)
+
+/*
+ * XACT_FLAGS_REMOTEMODIFIED - set when modify remote data or lock remote rows.
+ * We need it to check if replica read is suitable in a transaction.
+ */
+#define XACT_FLAGS_REMOTEMODIFIED				     (1U << 4)
+
+/*
+ * XACT_FLAGS_ONEREMOTEREQ - set when only one remote sql to be execute in a whole transaction
+ */
+#define XACT_FLAGS_ONEREMOTEREQ						(1U << 5)
+
+/*
+ * XACT_FLAGS_MULTI_STMTS - set when client send multi statements at a time.
+ */
+#define XACT_FLAGS_MULTI_STMTS						(1U << 6)
+
+/*
+ * XACT_FLAGS_DISABLE_STMT_SUBXACT - set when a subtransaction used to wrap
+ * client statement cannot be start or rollback.
+ */
+#define XACT_FLAGS_DISABLE_STMT_SUBXACT				(1U << 7)
+
 /*
  *	start- and end-of-transaction callbacks for dynamically loaded modules
  */
@@ -406,6 +440,11 @@ extern void UnregisterXactCallback(XactCallback callback, void *arg);
 extern void RegisterSubXactCallback(SubXactCallback callback, void *arg);
 extern void UnregisterSubXactCallback(SubXactCallback callback, void *arg);
 
+extern bool IsKunlunInternalStmtSubXact(void);
+extern void BeginKunlunInternalStmtSubXact(void);
+extern void ReleaseKunlunInternalStmtSubXact(void);
+extern void AbortKunlunInternalStmtSubXact(void);
+
 extern int	xactGetCommittedChildren(TransactionId **ptr);
 
 extern XLogRecPtr XactLogCommitRecord(TimestampTz commit_time,
@@ -436,6 +475,6 @@ extern void EnterParallelMode(void);
 extern void ExitParallelMode(void);
 extern bool IsInParallelMode(void);
 extern bool IsExplicitTxn(void);
-extern const char *GetCurrentTransactionName(void);
 extern uint64_t GetCurrentGlobalTransactionId(void);
+extern void SetCurrentTxnExplicit(void);
 #endif							/* XACT_H */
