@@ -766,6 +766,7 @@ typedef enum
 	WAIT_EVENT_RECOVERY_WAL_ALL,
 	WAIT_EVENT_RECOVERY_WAL_STREAM,
 	WAIT_EVENT_SYSLOGGER_MAIN,
+	WAIT_EVENT_SQLLOGGER_MAIN,
 	WAIT_EVENT_WAL_RECEIVER_MAIN,
 	WAIT_EVENT_WAL_SENDER_MAIN,
 	WAIT_EVENT_WAL_WRITER_MAIN
@@ -834,7 +835,15 @@ typedef enum
 	WAIT_EVENT_REPLICATION_SLOT_DROP,
 	WAIT_EVENT_SAFE_SNAPSHOT,
 	WAIT_EVENT_SYNC_REP,
-	WAIT_EVENT_DEBUG_SYNC
+	WAIT_EVENT_DEBUG_SYNC,
+	WAIT_EVENT_SEQUENCE_SERVICE,
+	WAIT_EVENT_SHARD_RESULT,
+	WAIT_EVENT_2PC_PREPARE,
+	WAIT_EVENT_2PC_LOG,
+	WAIT_EVENT_2PC_COMMIT,
+	WAIT_EVENT_2PC_ROLLBACK,
+	WAIT_EVENT_GLOBAL_DDL_LOCK,
+	WAIT_EVENT_LATEST_DDL_META,
 } WaitEventIPC;
 
 /* ----------
@@ -996,6 +1005,7 @@ typedef struct PgBackendStatus
 
 	/* The entry is valid iff st_procpid > 0, unused if st_procpid == 0 */
 	int			st_procpid;
+	int			st_procvpid;
 
 	/* Type of backends */
 	BackendType st_backendType;
@@ -1351,8 +1361,8 @@ pgstat_report_wait_end(void)
 	(pgStatBlockWriteTime += (n))
 
 extern void pgstat_count_heap_insert(Relation rel, PgStat_Counter n);
-extern void pgstat_count_heap_update(Relation rel, bool hot);
-extern void pgstat_count_heap_delete(Relation rel);
+extern void pgstat_count_heap_update(Relation rel, bool hot, PgStat_Counter n);
+extern void pgstat_count_heap_delete(Relation rel, PgStat_Counter n);
 extern void pgstat_count_truncate(Relation rel);
 extern void pgstat_update_heap_dead_tuples(Relation rel, int delta);
 
