@@ -270,6 +270,11 @@ typedef struct StdRdOptions
 	int			parallel_workers;	/* max number of parallel workers */
 	uint32_t    shard;          /* ID of the shard to store the table. */
 	int  engine;
+	int compression;
+	int row_format;
+	int encryption;
+	int autoextend_size;
+	int tablegroup;
 } StdRdOptions;
 
 #define HEAP_MIN_FILLFACTOR			10
