@@ -15,6 +15,7 @@ import add_comp_nodes
 import install_pg
 import sys
 import psycopg2
+from common import my_print
 
 # config file format:
 #
@@ -54,7 +55,7 @@ def add_comp_self(install_path, config_template_file, mysql_conn_params, config_
     meta_cursor.execute("commit")
     maxid = 1 
     if row is not None and row[0] is not None:
-	maxid = int(row[0])
+        maxid = int(row[0])
     meta_cursor.close()
     meta_conn.close()
 
@@ -136,4 +137,4 @@ if __name__ == '__main__':
     mysql_conn_params['database'] = 'Kunlun_Metadata_DB'
             
     add_comp_self(install_path, config_template_file, mysql_conn_params, "self.json", args)
-    print "Current computing node successfully added to cluster " + args.cluster_name
+    my_print("Current computing node successfully added to cluster " + args.cluster_name)
