@@ -414,7 +414,7 @@ CREATE PROCEDURE `append_ddl_log_entry`(
   obj_type varchar(16),
   op_type varchar(16),
   cur_opid bigint unsigned,
-  sql_src text,
+  sql_src mediumtext,
   sql_src_sn text,
   target_shardid int unsigned,
   initiator_id int unsigned,
